import axios from 'axios'
import { INIT_PAYMENTS_PURCHASES_URL, PAYMENTS_PURCHASES_PROCESS_URL } from '@/constants/resourcePaths'

const state = {
    processingPaymentsPurchases: false,
    completedPaymentsPurchases: false
}

const getters = {
    /**
     * [processingPaymentsPurchases description]
     */
    processingPaymentsPurchases ( state ) {
        return state.processingPaymentsPurchases
    },
    /**
     * [completedPaymentsPurchases description]
     */
    completedPaymentsPurchases ( state ) {
        return state.completedPaymentsPurchases
    }
}

const mutations = {
    /**
     * [completedPaymentsPurchases description]
     */
    setProcessingPaymentsPurchases (state, payload ) {
        state.processingPaymentsPurchases = payload
    },
    /**
     * [completedPaymentsPurchases description]
     */
    setCompletedPaymentsPurchases ( state, payload ) {
        state.completedPaymentsPurchases = payload
    }
}

const actions = {
    /**
     * [PAYMENTS_PURCHASES_NOTIFY]
     */
    paymentsPurchasesNotify ({ commit }, paylod) {
        openerp.web.notification.do_warn('Atencion', paylod)
        return false
    },
    /**
     * [response description]
     */
    initPaymentsPurchases({ dispatch }) {
        return axios.get(INIT_PAYMENTS_PURCHASES_URL).then(response => {
            dispatch('completedPaymentsPurchases', false)
            dispatch('explodeData', response.data)
        }).catch(error => {
            console.log(error);
        } )
    },
    /**
     *  [EXPLODE_DATA]
     */
    explodeData ({ dispatch },paylod) {
        for (let value in paylod) {
            dispatch(`initPaymentsPurchases${value[0].toUpperCase()}${value.slice(1)}`, paylod[value])
        }
    },
    /**
     * [PAYMENTS_PURCHASE_PROCESS]
     */
    paymentsPurchaseProcess ({ commit, dispatch, getters }){
        commit('setProcessingPaymentsPurchases', true)
        const data = {
            jsonrpc: '2.0',
            method: 'call',
            params: {
                journalId: getters.paymentsSelectedJournal.id,
                amountPayments: getters.paidTotal <= getters.paymentsTotal ? getters.paidTotal : getters.paymentsTotal,
                supplierId: getters.selectedSupplier.id,
                invoiceId: getters.selectedInvoices.id,
                journalType: getters.paymentsSelectedJournal.type,
                bankId: getters.paymentsSelectedJournal.type ==='bank' ? getters.selectedPaymentsBank.id : '',
                bankTypeId: getters.paymentsSelectedJournal.type ==='bank' ? getters.selectedPaymentsBankType.id : '',
                bankRef: getters.paymentsSelectedJournal.type ==='bank' ? getters.paymentsBankRef : '',
                bankDateMaturity: getters.paymentsSelectedJournal.type ==='bank' ? getters.paymentsBankDateMaturity : '',
                paymentsBankNumber_cta: getters.paymentsSelectedJournal.type ==='bank' ? getters.paymentsBankNumberCta : '',
                paymentsBankName_holder: getters.paymentsSelectedJournal.type ==='bank' ? getters.paymentsBankNameHolder : '',
                numberChBankId: !!getters.numberChBankId ?  getters.numberChBankId : '',
                moveLinesId: getters.paymentsMoveLines.map( item => {
                    return item.id
                })
            }
        }
        return axios.post(PAYMENTS_PURCHASES_PROCESS_URL, data).then(response => {
            commit('setProcessingPaymentsPurchases', !response.data.result)
            dispatch('completedPaymentsPurchases', response.data.result)
        }).catch(error => {
            commit('setProcessingPaymentsPurchases', !false)
        })
    },
    /**
     * [COMPLETED_PAYMENTS_PURCHASES] [Cambiar el estado cunado se completa el pago]
     */
    completedPaymentsPurchases ({ commit }, payload ) {
        commit('setCompletedPaymentsPurchases', !!payload)
    },
    /**
     *  [RESET_PAYMENTS_PURCHASES]
     */
    resetPaymentsPurchases ({ rootState, commit, dispatch }) {
        for (let key in rootState ) {
            if (!(rootState[key] instanceof Object)){
                continue
            }
            dispatch(`reset${key[0].toUpperCase()}${key.slice(1)}`)
        }
        dispatch('initPaymentsPurchases')
    },
    /**
     * [CHECK_PAYMENTS_PURCHASES_SUPPLIER] [Validar que seleccione un proveedor]
    */
    checkPaymentsPurchasesSupplier ({ dispatch, getters }) {
        return !!getters.selectedSupplier || dispatch('paymentsPurchasesNotify', 'Necesitas seleccionar un proveedor para continuar.')
    },
    /**
      * [CHECK_PAYMENTS_PURCHASES_INVOICES] [validar que selecciones una factura]
      */
    checkPaymentsPurchasesInvoices ({ dispatch, getters}) {
        return !!getters.selectedInvoices || dispatch('paymentsPurchasesNotify', 'Necesitas seleccionar una factura para continuar.')
    },
    /**
      * [CHECK_PAYMENTS_PURCHASES_LINES_PAYMENTS] [validar que seleccione al menos una cuota a apagar]
      */
    checkPaymentsPurchasesLinesPayments ({ dispatch, getters }) {
         return !!getters.supplierLinesPayments.length || dispatch('paymentsPurchasesNotify', 'Necesitas seleccionar al menos una cuota para continuar.')
    },
     /**
      * [CHECK_PAYMENTS_PURCHASES_JOURNALS] [validar que seleccione el método de pago, ingrese el monto a pagar]
      */
    checkPaymentsPurchasesJournals ({ dispatch, getters }) {
        if (getters.paymentsSelectedJournal.length <= 0) {
            return dispatch('paymentsPurchasesNotify', 'Necesitas seleccionar el método para continuar.')
        }

        if (getters.paidTotal <= 0){
            return dispatch('paymentsPurchasesNotify', 'El monto no puede ser cero(0), ingrese un monto para continuar.')
        }

        if (getters.paymentsSelectedJournal && getters.paymentsSelectedJournal.type ==='bank') {
            if (!getters.selectedPaymentsBank || getters.selectedPaymentsBank.length <= 0) {
                return dispatch('paymentsPurchasesNotify', 'Necesitas seleccionar un banco')
            }
            if (!getters.selectedPaymentsBankType || getters.selectedPaymentsBankType.length <= 0) {
                return dispatch('paymentsPurchasesNotify', 'Necesitas seleccionar el tipo de transacción bancaria')
            }
            if (!getters.paymentsBankRef){
                return dispatch('paymentsPurchasesNotify', 'Necesitas ingresar el Nº cheque / boleta')
            }
            if (!getters.paymentsBankDateMaturity){
                return dispatch('paymentsPurchasesNotify', 'Necesitas ingresar una fecha de vencimiento')
            }
        }
        return true
    },
     /**
      * [prev description] [Cuando pasa de un Estado Superior a inferior u cuando abandona el modulo restaura los datos]
      */
    setChangeTabSteps ({ commit, dispatch, getters }, paylod) {
        /* Si abandona el modulo */
        if (paylod.prev === 0 && paylod.next === -1){
            dispatch('resetPaymentsPurchases')
        }

        if (paylod.prev >= 2 && paylod.next<= 1) {
            dispatch('changeInitialPaid', 0)
            dispatch('actionRemoveAllSupplierLinesPayments')
        }
    }
}

export default {
    state,
    getters,
    mutations,
    actions
}
