const initialState = {
    supplier: [],
    filterSupplier:[],
    loadingSupplier: false,
    selectedSupplier: null
}

const state = {
    supplier: initialState.supplier,
    loadingSupplier: initialState.loadingSupplier,
    filterSupplier: initialState.filterSupplier,
    selectedSupplier: initialState.selectedSupplier
}

const getters = {
    /**
     * [supplier description]
     */
    supplier ( state ) {
        return state.supplier
    },
    /**
     * [loadingSupplier description]
     */
    loadingSupplier ( state ) {
        return !state.loadingSupplier
    },
    /**
     * [selectedSupplier description]
     */
    selectedSupplier ( state ) {
        return state.selectedSupplier
    },
    /**
     * [supplierVisible description]
     */
    supplierVisible ( state ) {
        return state.filterSupplier.length === 0 ? state.supplier : state.filterSupplier
    }
}

const mutations = {
    /**
     * [supplier description]
     */
    setSupplier (state, payload) {
        state.supplier = payload
    },
    /**
     * [loadingSupplier description]
     */
    setLoadingSupplier (state, payload) {
        state.loadingSupplier = payload
    },
    /**
     * [filterSupplier description]
     */
    setFilterPaymentsPurchasesSupplier (state, payload) {
        state.filterSupplier = payload
    },
    /**
     * [selectedSupplier description]
     */
    setSelectedPaymentsPurchasesSupplier ( state, payload ) {
        state.selectedSupplier = payload
    }
}

const actions = {
    /**
     * [INIT_PAYMENTS_PURCHASES_SUPPLIER]
     */
    initPaymentsPurchasesSupplier ({ commit },payload) {
        commit('setSupplier', payload)
        commit('setLoadingSupplier', payload)
    },
    /**
     * [ FILTER_PAYMENTS_PURCHASES_SUPPLIER ]
     */
    filterPaymentsPurchasesSupplier ({ commit }, payload) {
        commit('setFilterPaymentsPurchasesSupplier', payload)
    },
    /**
     * [SELECT_PAYMENTS_PURCHASES_SUPPLIER]
     */
    selectPaymentsPurchasesSupplier ({ commit, dispatch }, payload) {
        commit('setSelectedPaymentsPurchasesSupplier', payload)

        dispatch('initSupplierInvoices', payload.invoices)
    },
    /**
     * [RESET_PAYMENTS_PURCHASES_SUPPLIER]
     */
    resetPaymentsPurchasesSupplier ({ commit}) {
        commit('setSupplier', [])
        commit('setLoadingSupplier', true)
        commit('setFilterPaymentsPurchasesSupplier', [])
        commit('setSelectedPaymentsPurchasesSupplier', null)
    }
}


export default {
    state,
    getters,
    mutations,
    actions
}
