const intialState = {
    supplierMoveLines: [],
    selectdLines: [],
    supplierLinesPayments: [],
    supplierPaymentsTotal: 0
}

const  state = {
    supplierMoveLines: intialState.supplierMoveLines,
    selectdLines: intialState.selectdLines,
    supplierLinesPayments: intialState.supplierLinesPayments,
    supplierPaymentsTotal: intialState.supplierPaymentsTotal
}

const getters = {
    /**
     * [supplierMoveLines description]
     */
    supplierMoveLines ( state ) {
        return state.supplierMoveLines
    },
    /**
     * [selectdLines description]
     */
    selectdLines ( state ){
        return state.selectdLines
    },
    /**
     * [supplierLinesPayments description]
     */
    supplierLinesPayments ( state ) {
        return state.supplierLinesPayments
    },
    /**
     * [supplierPaymentsTotal description]
     */
    supplierPaymentsTotal ( state ) {
        return state.supplierPaymentsTotal
    }
}

const mutations = {
    /**
     * [supplierInvoices description]
     */
    setSupplierMoveLines (state, payload) {
        state.supplierMoveLines = payload
    },
    /**
     * [selectdLines description]
     */
    setSelectedSupplierMoveLines ( state, payload) {
        state.selectdLines = payload
    },
    /**
     * [supplierLinesPayments description]
     */
    setSupplierLinesPayments (state, payload) {
        state.supplierLinesPayments = [payload, ...state.supplierLinesPayments]
    },
    /**
     * [amountTot description]
     */
    removeSupplierMoveLines ( state, payload ) {
        let moveFoundIndex = state.supplierMoveLines.findIndex(item => item.id === payload.id)
        state.supplierMoveLines.splice(moveFoundIndex, 1)
    },
    /**
     * [mode description]
     */
    removeSupplierLinesPayments (state, payload ) {
        if (payload.mode === 'full') {
            payload.moveLines.forEach(moves => {
                //ADD supplierMoveLines
                let movesFound = state.supplierMoveLines.find(item => item.id === moves.id)
                if (movesFound) return
                state.supplierMoveLines = [moves, ...state.supplierMoveLines]
                // Remove Payments
                let movesPaymentsIndex = state.supplierLinesPayments.findIndex(item => item.id === moves.id)
                state.supplierLinesPayments.splice(movesPaymentsIndex)
            })
        } else {
            //ADD supplierMoveLines
            let movesFound = state.supplierMoveLines.find(item => item.id === payload.moveLines.id)
            if (movesFound) return
            state.supplierMoveLines = [payload.moveLines, ...state.supplierMoveLines]
            // Remove Payments
            let movesPaymentsIndex = state.supplierLinesPayments.findIndex(item => item.id === payload.moveLines.id)
            state.supplierLinesPayments.splice(movesPaymentsIndex, 1)
        }
    },
    /**
     * [mode description]
     */
    removeLinesPayments(state, payload ) {
        if (payload.mode === 'full') {
            payload.moveLines.forEach(moves => {
                // Remove Payments
                let movesPaymentsIndex = state.supplierLinesPayments.findIndex(item => item.id === moves.id)
                state.supplierLinesPayments.splice(movesPaymentsIndex)
            })
        } else {
            // Remove Payments
            let movesPaymentsIndex = state.supplierLinesPayments.findIndex(item => item.id === payload.moveLines.id)
            state.supplierLinesPayments.splice(movesPaymentsIndex, 1)
        }
    },
    /**
     * [amountTot description]
     */
    setCalculateTotal ( state ) {
        let amountTot = 0
        if (state.supplierLinesPayments.length > 0)
            state.supplierLinesPayments.forEach( item => {
                amountTot = amountTot + item.amountResidualCurrency
            })

        state.supplierPaymentsTotal =  amountTot
    },
    /**
     * [supplierMoveLines description]
     */
    setOrderSUpplierMoveLines ( state ) {
        state.supplierMoveLines =  state.supplierMoveLines.sort((a, b) => {
            return a.dateMaturity > b.dateMaturity
        })
    },
    /**
     * [supplierLinesPayments description]
     */
    setOrderSupplierLinesPayments ( state ) {
        state.supplierLinesPayments =  state.supplierLinesPayments.sort((a, b) => {
            return a.dateMaturity > b.dateMaturity
        })
    }
}

const actions = {
    /**
     * [INIT_SUPPLIER_MOVE_LINES]
     */
    initSupplierMoveLines ({ commit }, payload) {
        commit('setSupplierMoveLines', payload)
        commit('setOrderSUpplierMoveLines')
    },
    /**
     *  [SELECT_SUPPLIER_MOVE_LINES]
     */
    selectSupplierMoveLines ({ commit, dispatch }, payload) {
        // payments
        commit('setSupplierLinesPayments', payload)
        commit('setOrderSupplierLinesPayments')
        commit('setSelectedSupplierMoveLines', payload)
        commit('removeSupplierMoveLines', payload)
        commit('setCalculateTotal')
        dispatch('addPaymentsMoveLines', payload)
    },
    /**
    * [mode description
    */
    actionRemoveSupplierLinesPayments ( {commit, dispatch}, payload ) {
        dispatch('addMoveInInvoice', {
            mode: 'partial',
            moveLines: payload
        })
        commit('removeSupplierLinesPayments', {
            mode: 'partial',
            moveLines: payload
        })
        dispatch('removePaymentsMoveLines', {
            mode: 'partial',
            moveLines: payload
        })
        // Total
        commit('setCalculateTotal')
        commit('setOrderSUpplierMoveLines')
    },
    /**
     * [mode description]
     * @type {String}
     */
    actionRemoveAllSupplierLinesPayments ({ commit, dispatch, getters }) {

        dispatch('addMoveInInvoice', {
            mode: 'full',
            moveLines: getters.supplierLinesPayments.map(item => {
                return item
            })
        })
        dispatch('removePaymentsMoveLines', {
            mode: 'full',
            moveLines: getters.supplierLinesPayments.map(item => {
                return item
            })
        })
        dispatch('resetSelectedJournalPayments')
        commit('removeSupplierLinesPayments', {
            mode: 'full',
            moveLines: getters.supplierLinesPayments.map(item => {
                return item
            })
        })
        commit('setCalculateTotal')
        commit('setOrderSUpplierMoveLines')
    },
    /**
     * [RESET_SUPPLIER_MOVE_LINES]
     */
    resetSupplierMoveLines ({ commit, getters }){
        commit('setSupplierMoveLines', [])
        commit('setSelectedSupplierMoveLines', [])
        commit('removeLinesPayments', {
                mode: 'full',
                moveLines:getters.supplierLinesPayments
        })
        commit('setCalculateTotal')
    }
}

export default {
    state,
    getters,
    mutations,
    actions
}
